#version 430 core

in vec3 worldNormal;
in vec3 fragmentPos;
in vec2 fragmentUV;

layout(location = 0) out vec4 outColor;

uniform sampler2D color_texture;
uniform vec3 light_color;
uniform vec3 light_pos;
uniform vec3 view_dir;

void main() {
	float ambk = 0.1f;
	vec3 ambient = ambk * light_color;

	vec3 norm = normalize(worldNormal);
	vec3 lightDir = normalize(light_pos - fragmentPos);

	float diff = max(dot(norm, lightDir), 0.0f);
	vec3 diffuse = diff * light_color;

	vec3 viewDir = normalize(-view_dir);
	vec3 reflectDir = reflect(-lightDir, norm);

	float sk = 0.5;
	float spec = pow(max(dot(viewDir, reflectDir), 0.0), 16);
	vec3 specular = sk * spec * light_color;  

	vec3 textureColor = texture(color_texture, fragmentUV).rgb;
	outColor = vec4((ambient + diffuse + specular) * textureColor, 1.0);
}